
### CFAC R Workshop 5/9/2016 - Exercise 2 - Data Visualization


# setwd stands for "set working directory" -
# In other words, it is the location of the data you want to import into R
setwd('C:/Users/suttonst/Desktop/CFAC/CFAC R Workshop Files/Datasets')


# Read in our CSV data file into R as a data frame, "test_dat"
test_dat = read.csv(file='science_exam_scores_CFAC.csv',head=TRUE)


# Convert the school number variable from "integer" to "factor"
test_dat$SchoolNum = as.factor(test_dat$SchoolNum)


#the levels() command allows you to see a list of all unique values
levels(test_dat$test_name)


# Frequency table of test names
table(test_dat$test_name)


# Frequency table of school names
table(test_dat$SchoolName)


# How many rows are contained with the test_dat data frame?
nrow(test_dat)


### Subsetting data
# This will take all rows of the original data frame, test_dat, where the SchoolNum is equal to "3"
# The first argument of the subset() command is the name of the data frame you are subetting, test_dat in our case"
# The second argument is the condition on which you are subsetting the data
# The first time this code is executed, all rows 
school_3 = subset(test_dat, test_dat$SchoolNum == "3")

# Basic plotting
# the tilda key, "~" can be interpreted as "by"
# Here we are saying "For the given data frame, "school_3", plot all of the scores by test name"
plot(school_3$score~school_3$test_name)

### For Loop
# The following code 


# The below line says "for every unique test name, run the following code:
# The first time this this code executes, the first test name will be stored into the variable i
# Everything contained within {} is what will be ran for each iteration
for (i in levels(test_dat$test_name)){

  ## This command subsets our original data frame
  ## We temporarily store this subsetted data frame into 'tdf' AKA - "temporary data frame"
  
  tdf = subset(test_dat,test_dat$test_name == i)
  
  # Drop unused levels
  tdf = droplevels(tdf)
  
  
  ## The boxplot command
  # In R, think of the tilda '~' key as the word "BY"
  # The first argument is saying "plot exam scores BY school"
  # The 'outline' option specifies whether outliers should be plotted or not
  # The 'las' option specifies the orientation of axis labels (horizonal vs vertical)
  # The 'col' option specifies a fill color for the boxplots
  # The 'ylab' option specifies the y-axis label
  # The 'xlab' option specifies the x-axis label
  # The 'ylim' option specifies the y-axis limits
  # R will supply its own axis limits if they are not explicitly provided here
  
  boxplot(tdf$score ~ tdf$SchoolNum,
          outline=F,
          las=2,
          col='grey',
          main=i,
          ylab="Raw Exam Score",
          xlab="School Number",
          ylim=c(0,100))
  
}



## Distribution graphs -- Add comments

## Subset original dataframe where test name = "Science 3 Cycle 1"
sci3_cycle1 = subset(test_dat,test_dat$test_name == "Science 3 Cycle 1")

## Subset original dataframe where test name = "Science 3 Cycle 2"
sci3_cycle2 = subset(test_dat,test_dat$test_name == "Science 3 Cycle 2")

# Store the median of the Science 3 - Cycle 1 exam scores into a variable
sci3_cycle1_med = median(sci3_cycle1$score)

# store the median of the Science 3 - Cycle 2 exam scores into a variable
sci3_cycle2_med = median(sci3_cycle2$score)


# The plot(density()) command will plot the distribution of the given variable
# The 'lty' option specifies the "line type" (dashed, solid, etc...)
# Type help.search("lty"), and click on the "graphics::par" help page, there you will find the available line type options
# The 'lwd' option specifies the "line width"

plot(density(sci3_cycle1$score),
     main = "Distribution of Science 3 Cycle Exam Scores",
     ylab = "Proportion of Population",
     xlab = "Exam Score",
     lty=1,
     lwd=2)

# The lines() command will add a specified plot to an already existing plot
# In other words, we are going to overlay the distribution of Cycle 2 exam scores on the distribution of Cycle 1 exam scores
# This will allow you to draw conclusions about overall exam performance
# Before utilizing this plot, ensure that both variables (exam scores) are on the same scale

  lines(density(sci3_cycle2$score), lty = 3, lwd = 2)

  # The abline() command allows you to draw a vertical or horizontal line at a specified location
  # Remember lty and lwd specify line type and line width respectively

  abline(v = sci3_cycle1_med, lty = 1, lwd = 1)

  abline(v = sci3_cycle2_med, lty = 3, lwd = 1)

  # The legend() command will draw a legend on the currently existing plot
  # The 'x' and 'y' options specificy the location of the legend
  # The legend option specifies the text to appear
  # By supplying lty and lwd values, we can draw line segments in the legend
  legend(x=0,y=0.02,legend=c("SCI 3 CYCLE 1","SCI 3 CYCLE 2"),lty=c(1,3),lwd=2,cex=0.8)

  # The text command will draw text on an existing plot
  # Again, 'x' and 'y' options specify the location of the text
  # The next option specifies the text to be drawn
  # The 'pos' option specifies orientation relative to the proviced coordinates
  # pos = 1 -> "Below" | pos = 2 -> "Left" | pos = 3 -> "Above" | pos = 4 -> "Right"
  # the cex command (cex = "character extension") specifies the text size
  
  text(x=(sci3_cycle1_med), y=0.01, "CYCLE 1 MEDIAN \n 46.67", pos=2, cex=0.6)

  text(x=(sci3_cycle2_med), y=0.005, "CYCLE 2 MEDIAN \n 53.49",pos=4, cex=0.6)

  # t.test() performs a t-test on two sets of data
  # A t-test is used to determine if two data sets are significantly different
  # A p-value < 0.05 is typically considered to be "statistically significant"
  
  t.test(sci3_cycle1$score,sci3_cycle2$score)
  
  # Here are p-value is < 2.2 x 10^-16
  # In other words, our p-value is very close to 0
  # Our scores are significantly differnt!
  
