
### CFAC R Workshop 5/9/2016 - Exercise 3 - Item Analysis (CTT/IRT)


# All example data provided with packages


# ======================== PART 1 ======================== #


# Load 'CTT (Classical Test Theory)' library
library(CTT)

data(CTTdata)
data(CTTkey)

# Scores for each preson
# the 'score' command takes three arguments, see the help output for a detailed description.
?score

# The output of 'score' is a list of two matricies
myScores <- score(CTTdata,CTTkey, output.scored=TRUE)

# The first matrix, titled "score" are the scores for each individual test taker
myScores$score

# The second matrix, titled "scored"  contains a binary matrix of 1's and 0's for each individual
# A value of 1 = correct answer, 0 = incorrect answer
myScores$scored

# Examples of basic statistics
max(myScores$score)

min(myScores$score)

range(myScores$score)

sd(myScores$score)

mean(myScores$score)

median(myScores$score)

mode(myScores$score)

# While R tends to be a very intuitive programming language 
# it is always important to check that the command is performing as you expect it to


## For Loop

# For loop to generate a Classical Test Theory - Item Characteristic Curve for each item on the assessment
for (i in 1:20){
  
  # Create a title for my graphs
  # This code takes the current loop iteration (i) and concatenates it onto the end of the provided text
  title_text = paste("Item Characteristic Curve - #",i,sep="")
  
  # The cttICC command creates an Item Characteristic Curve for each item on our test
cttICC(myScores$score, myScores$scored[,i], colTheme="spartans", cex=1.5,plotTitle = title_text)
}


# ======================== END PART 1 ======================== #





# ======================== PART 2 ======================== #

# Load 'psychometric' library
library(psychometric)

# Bring up documentation of the 'item.exam' command in the help window
?item.exam

# Save the output of 'item.exam' to a data frame names 'item_analysis'
# The command item.exam takes up to three arguments, see the output of the help page for a detailed description
item_analysis = item.exam(myScores$scored ,discrim=TRUE)

# Print the contents of 'item_analysis'
print(item_analysis)

# Output contents of 'item_analysis' to a .CSV file
write.csv(item_analysis, file="ItemAnalysis1.csv")


# ======================== END PART 2 ======================== #



# ======================== PART 3 ======================== #

## Item Response Theory

# Load the 'ltm' library
library(ltm)

# Examine the sample data set
?LSAT

### Fit a three-parameter model under the IRT approach
LSAT_TPM = tpm(LSAT)

# Check help documentation on the 'summary' command
?summary.tpm

# See the summary of the model fit
summary.tpm(LSAT_TPM)

# Assess model fit
item.fit(LSAT_TPM)



### Fit a rasch model (1 parameter) to the LSAT dataset
LSAT_rasch = rasch(LSAT)

# See the summary of the model fit
summary.rasch(LSAT_rasch)

# Assess model fit
GoF.rasch(LSAT_rasch)



### Fit a two-parameter model un the IRT approach
?ltm

LSAT_LTM = ltm(LSAT ~ z1)

# See the summary of the model fit
summary.ltm(LSAT_LTM)

# Assess model fit
item.fit(LSAT_LTM)


## when testing the item fit of an IRT model, a significant p-value indicates poor model fit
## the LSAT_rasch model is the only one with acceptable 'fit'
# Therefore, let's visualize our Rasch model:

# Plot the Item Characteristic Curves
plot(LSAT_rasch,type="ICC")

# Plot the Item Information Curves
plot(LSAT_rasch,type="IIC")


